==> jc-1.4.0.tar.gz: java/lang/ArrayStoreException.h <==
// public class java.lang.ArrayStoreException

// class file dependencies
// @dep_class e81a5694acf5fb26 java_lang_ArrayStoreException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_ArrayStoreException_H_
#define _JC_java_lang_ArrayStoreException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_ArrayStoreException$sub_refs	_jc_java_lang_ArrayStoreException$sub_refs;
typedef struct _jc_java_lang_ArrayStoreException$sub_nonrefs	_jc_java_lang_ArrayStoreException$sub_nonrefs;
typedef struct _jc_java_lang_ArrayStoreException$refs	_jc_java_lang_ArrayStoreException$refs;
typedef struct _jc_java_lang_ArrayStoreException$nonrefs	_jc_java_lang_ArrayStoreException$nonrefs;
typedef struct _jc_java_lang_ArrayStoreException$object	_jc_java_lang_ArrayStoreException$object;

typedef struct _jc_java_lang_ArrayStoreException$fields_struct	_jc_java_lang_ArrayStoreException$fields_struct;
typedef const struct _jc_java_lang_ArrayStoreException$vmethods	_jc_java_lang_ArrayStoreException$vmethods;
typedef const struct _jc_java_lang_ArrayStoreException$vtable	_jc_java_lang_ArrayStoreException$vtable;
typedef const struct _jc_java_lang_ArrayStoreException$vtype	_jc_java_lang_ArrayStoreException$vtype;

// Class fields structure
struct _jc_java_lang_ArrayStoreException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ArrayStoreException$fields_struct _jc_java_lang_ArrayStoreException$class_fields;

// Constructors
extern void _jc_java_lang_ArrayStoreException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ArrayStoreException$object *);
extern void _jc_java_lang_ArrayStoreException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ArrayStoreException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_ArrayStoreException$vmethods {
};

// Vtable
struct _jc_java_lang_ArrayStoreException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_ArrayStoreException$vmethods	java_lang_ArrayStoreException;
};

// Vtype
struct _jc_java_lang_ArrayStoreException$vtype {
	_jc_type			type;
	_jc_java_lang_ArrayStoreException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ArrayStoreException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ArrayStoreException$refs {
    _jc_java_lang_ArrayStoreException$sub_refs	java_lang_ArrayStoreException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ArrayStoreException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ArrayStoreException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_ArrayStoreException$sub_nonrefs	java_lang_ArrayStoreException;
};

// Object instance structure
struct _jc_java_lang_ArrayStoreException$object {
	_jc_java_lang_ArrayStoreException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ArrayStoreException$vtype	*vtype;
	_jc_java_lang_ArrayStoreException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ArrayStoreException$vtype _jc_java_lang_ArrayStoreException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ArrayStoreException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ArrayStoreException$class_object;

#endif	/* _JC_java_lang_ArrayStoreException_H_ */

==> jc-1.4.6.tar.gz: java/lang/ArrayStoreException.h <==
// public class java.lang.ArrayStoreException

// class file dependencies
// @dep_class e81a5694acf5fb26 java_lang_ArrayStoreException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_ArrayStoreException_H_
#define _JC_java_lang_ArrayStoreException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_ArrayStoreException$sub_refs	_jc_java_lang_ArrayStoreException$sub_refs;
typedef struct _jc_java_lang_ArrayStoreException$sub_nonrefs	_jc_java_lang_ArrayStoreException$sub_nonrefs;
typedef struct _jc_java_lang_ArrayStoreException$refs	_jc_java_lang_ArrayStoreException$refs;
typedef struct _jc_java_lang_ArrayStoreException$nonrefs	_jc_java_lang_ArrayStoreException$nonrefs;
typedef struct _jc_java_lang_ArrayStoreException$object	_jc_java_lang_ArrayStoreException$object;

typedef struct _jc_java_lang_ArrayStoreException$fields_struct	_jc_java_lang_ArrayStoreException$fields_struct;
typedef const struct _jc_java_lang_ArrayStoreException$vmethods	_jc_java_lang_ArrayStoreException$vmethods;
typedef const struct _jc_java_lang_ArrayStoreException$vtable	_jc_java_lang_ArrayStoreException$vtable;
typedef const struct _jc_java_lang_ArrayStoreException$vtype	_jc_java_lang_ArrayStoreException$vtype;

// Class fields structure
struct _jc_java_lang_ArrayStoreException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ArrayStoreException$fields_struct _jc_java_lang_ArrayStoreException$class_fields;

// Constructors
extern void _jc_java_lang_ArrayStoreException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ArrayStoreException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ArrayStoreException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ArrayStoreException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_ArrayStoreException$vmethods {
};

// Vtable
struct _jc_java_lang_ArrayStoreException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_ArrayStoreException$vmethods	java_lang_ArrayStoreException;
};

// Vtype
struct _jc_java_lang_ArrayStoreException$vtype {
	_jc_type			type;
	_jc_java_lang_ArrayStoreException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ArrayStoreException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ArrayStoreException$refs {
    _jc_java_lang_ArrayStoreException$sub_refs	java_lang_ArrayStoreException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ArrayStoreException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ArrayStoreException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_ArrayStoreException$sub_nonrefs	java_lang_ArrayStoreException;
};

// Object instance structure
struct _jc_java_lang_ArrayStoreException$object {
	_jc_java_lang_ArrayStoreException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ArrayStoreException$vtype	*vtype;
	_jc_java_lang_ArrayStoreException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ArrayStoreException$vtype _jc_java_lang_ArrayStoreException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ArrayStoreException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ArrayStoreException$class_object;

#endif	/* _JC_java_lang_ArrayStoreException_H_ */
